summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorChia-I Wu <olvaffe@gmail.com>2014-08-26 13:41:11 +0800
committerChia-I Wu <olvaffe@gmail.com>2014-08-26 14:10:50 +0800
commit6c73478223a0ed76e54f14c46831974c3efaacdf (patch)
treefc9071149c222ac5679c2fb73dae11507698d284 /src
parent354d84b6297fe2937e9684175ea9d3b650b75417 (diff)
ilo: rename intel_bo_map_unsynchronized()
Rename it to intel_bo_map_gtt_async().
Diffstat (limited to 'src')
-rw-r--r--src/gallium/drivers/ilo/ilo_transfer.c13
-rw-r--r--src/gallium/drivers/ilo/ilo_transfer.h4
-rw-r--r--src/gallium/winsys/intel/drm/intel_drm_winsys.c2
-rw-r--r--src/gallium/winsys/intel/intel_winsys.h5
4 files changed, 11 insertions, 13 deletions
diff --git a/src/gallium/drivers/ilo/ilo_transfer.c b/src/gallium/drivers/ilo/ilo_transfer.c
index a38708d88a6..de6f4324b9a 100644
--- a/src/gallium/drivers/ilo/ilo_transfer.c
+++ b/src/gallium/drivers/ilo/ilo_transfer.c
@@ -224,7 +224,7 @@ xfer_unblock(struct ilo_transfer *xfer, bool *resource_renamed)
case ILO_TRANSFER_MAP_CPU:
case ILO_TRANSFER_MAP_GTT:
if (xfer->base.usage & PIPE_TRANSFER_UNSYNCHRONIZED) {
- xfer->method = ILO_TRANSFER_MAP_GTT_UNSYNC;
+ xfer->method = ILO_TRANSFER_MAP_GTT_ASYNC;
unblocked = true;
}
else if ((xfer->base.usage & PIPE_TRANSFER_DISCARD_WHOLE_RESOURCE) &&
@@ -238,7 +238,7 @@ xfer_unblock(struct ilo_transfer *xfer, bool *resource_renamed)
unblocked = true;
}
break;
- case ILO_TRANSFER_MAP_GTT_UNSYNC:
+ case ILO_TRANSFER_MAP_GTT_ASYNC:
case ILO_TRANSFER_MAP_STAGING:
unblocked = true;
break;
@@ -291,9 +291,8 @@ xfer_map(struct ilo_transfer *xfer)
case ILO_TRANSFER_MAP_GTT:
ptr = intel_bo_map_gtt(ilo_resource_get_bo(xfer->base.resource));
break;
- case ILO_TRANSFER_MAP_GTT_UNSYNC:
- ptr = intel_bo_map_unsynchronized(
- ilo_resource_get_bo(xfer->base.resource));
+ case ILO_TRANSFER_MAP_GTT_ASYNC:
+ ptr = intel_bo_map_gtt_async(ilo_resource_get_bo(xfer->base.resource));
break;
case ILO_TRANSFER_MAP_STAGING:
{
@@ -337,7 +336,7 @@ xfer_unmap(struct ilo_transfer *xfer)
switch (xfer->method) {
case ILO_TRANSFER_MAP_CPU:
case ILO_TRANSFER_MAP_GTT:
- case ILO_TRANSFER_MAP_GTT_UNSYNC:
+ case ILO_TRANSFER_MAP_GTT_ASYNC:
intel_bo_unmap(ilo_resource_get_bo(xfer->base.resource));
break;
case ILO_TRANSFER_MAP_STAGING:
@@ -953,7 +952,7 @@ tex_map(struct ilo_transfer *xfer)
switch (xfer->method) {
case ILO_TRANSFER_MAP_CPU:
case ILO_TRANSFER_MAP_GTT:
- case ILO_TRANSFER_MAP_GTT_UNSYNC:
+ case ILO_TRANSFER_MAP_GTT_ASYNC:
ptr = xfer_map(xfer);
if (ptr) {
const struct ilo_texture *tex = ilo_texture(xfer->base.resource);
diff --git a/src/gallium/drivers/ilo/ilo_transfer.h b/src/gallium/drivers/ilo/ilo_transfer.h
index d7f4838d384..e41edc1aa53 100644
--- a/src/gallium/drivers/ilo/ilo_transfer.h
+++ b/src/gallium/drivers/ilo/ilo_transfer.h
@@ -39,10 +39,10 @@
#define ILO_TRANSFER_MAP_BUFFER_ALIGNMENT 64
enum ilo_transfer_map_method {
- /* map() / map_gtt() / map_unsynchronized() */
+ /* map() / map_gtt() / map_gtt_async() */
ILO_TRANSFER_MAP_CPU,
ILO_TRANSFER_MAP_GTT,
- ILO_TRANSFER_MAP_GTT_UNSYNC,
+ ILO_TRANSFER_MAP_GTT_ASYNC,
/* use staging resource */
ILO_TRANSFER_MAP_STAGING,
diff --git a/src/gallium/winsys/intel/drm/intel_drm_winsys.c b/src/gallium/winsys/intel/drm/intel_drm_winsys.c
index 6f85852c264..2da7b02657a 100644
--- a/src/gallium/winsys/intel/drm/intel_drm_winsys.c
+++ b/src/gallium/winsys/intel/drm/intel_drm_winsys.c
@@ -510,7 +510,7 @@ intel_bo_map_gtt(struct intel_bo *bo)
}
void *
-intel_bo_map_unsynchronized(struct intel_bo *bo)
+intel_bo_map_gtt_async(struct intel_bo *bo)
{
int err;
diff --git a/src/gallium/winsys/intel/intel_winsys.h b/src/gallium/winsys/intel/intel_winsys.h
index c928cad4316..2f053146bb2 100644
--- a/src/gallium/winsys/intel/intel_winsys.h
+++ b/src/gallium/winsys/intel/intel_winsys.h
@@ -226,8 +226,7 @@ intel_bo_unreference(struct intel_bo *bo);
* sequential writes, but reads would be very slow. Callers always have a
* linear view of the bo.
*
* map_unsynchronized() is similar to map_gtt(), except that it does not
* block.
*/
void *
intel_bo_map(struct intel_bo *bo, bool write_enable);
@@ -236,7 +235,7 @@ void *
intel_bo_map_gtt(struct intel_bo *bo);
void *
-intel_bo_map_unsynchronized(struct intel_bo *bo);
+intel_bo_map_gtt_async(struct intel_bo *bo);
/**
* Unmap \p bo.
@@ -226,8 +226,7 @@ intel_bo_unreference(struct intel_bo *bo);
* linear view of the bo.
*
- * map_unsynchronized() is similar to map_gtt(), except that it does not
- * block.
+ * map_gtt_async() is similar to map_gtt(), except that it does not block.
*/
void *